@@ -1,4 +1,3 @@
-#### $Id: TA.plot.R,v 1.12 2014/06/13 12:29:24 maechler Exp $
 n.plot <-
     function(x, y=NULL, nam = NULL, abbr = n >= 20 || max(nchar(nam))>=8,
              xlab = NULL, ylab = NULL, log = "",
@@ -12,15 +11,12 @@ n.plot <-
     xlabel <- if (!missing(x)) deparse(substitute(x))
     ylabel <- if (!missing(y)) deparse(substitute(y))
     xy <- xy.coords(x, y, xlabel, ylabel, log)
-    xlab <- if (is.null(xlab)) xy$xlab else xlab
-    ylab <- if (is.null(ylab)) xy$ylab else ylab
+    xlab <- xlab %||% xy$xlab
+    ylab <- ylab %||% xy$ylab
     plot(xy, type = 'n', xlab = xlab, ylab = ylab, log = log, ...)
     n <- length(x)
-    if(is.null(nam)) {  nam <- rownames(x)
-     if (is.null(nam)) { nam <- names(x)
-      if (is.null(nam)) { nam <- names(y)
-       if (is.null(nam)) { nam <- paste(1:n) #- Use 1,2,.. if no names
-    }}}}
+    ## Use "any names", otherwise take  1,2,.. :
+    nam <- nam %||% rownames(x) %||% names(x) %||% names(y) %||% as.character(seq_len(n))
     if(abbr) nam <- abbreviate(nam, minlength=1)
     text(xy, labels=nam, cex=cex, col=col)
     invisible(nam)
@@ -51,7 +47,7 @@ TA.plot <-
   ## -------------------------------------------------------------------------
   ## Author: Martin Maechler, Date: Dec 92 / Nov.93;  for R: 1999/2000
   if(missing(main)) {
-    call <- lm.res $ call
+    call <- getCall(lm.res)
     if(is.call(call[["formula"]]) && any(c("lm", "aov") == call[[1]]))
       call <- call[["formula"]]
     else {  #-- only formula part; no extra  'data ='
@@ -82,8 +78,9 @@ TA.plot <-
       n.plot(fit, res, nam = labels, xlab = xlab, main = main, ...)
   } else {
       yl <- "Residuals"
-      if(!is.null(lm.res$weights) &&
-         any(abs(lm.res$resid- res) > 1e-6*mad(res)))
+      ## FIXME $weights, $resid -- not portable (e.g., to lmer obj!) ==> use extractors?
+      if(is.list(lm.res) && !is.null(lm.res$weights) && is.numeric(res0 <- lm.res$resid) &&
+         any(abs(res0 - res) > 1e-6*mad(res)))
           yl <- paste("WEIGHTED", yl)
       n.plot(fit, res, nam = labels, xlab = xlab, ylab = yl, main = main, ...)
   }
@@ -109,7 +106,7 @@ TA.plot <-
     if(!is.list(parSmooth)) stop("`parSmooth' must be a list")
     ##-- lo.iter: idea of Werner Stahel:  no robustness for 'glm'  residuals
     if (is.null(lo.iter))
-      lo.iter <- if(inherits(lm.res, "glm")&& lm.res$family[1]!="Gaussian")
+      lo.iter <- if(inherits(lm.res, "glm") && family(lm.res)$family[1] != "Gaussian")
 	0  else  3
     f <- max(0.2, 1.25 * n^-.2) #'-- Martin's very empirical formula...
     rlow <- lowess(fit, res, f = f, iter = lo.iter)
